/*
Copyright © 2023-2025 Philipp Wolfer <phw@uploadedlobster.com>

This file is part of Scotty.

Scotty is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scotty is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
Scotty. If not, see <https://www.gnu.org/licenses/>.
*/
package dump

import (
	"context"
	"fmt"

	"go.uploadedlobster.com/scotty/internal/config"
	"go.uploadedlobster.com/scotty/internal/models"
)

type DumpBackend struct{}

func (b *DumpBackend) Name() string { return "dump" }

func (b *DumpBackend) Options() []models.BackendOption { return nil }

func (b *DumpBackend) InitConfig(config *config.ServiceConfig) error {
	return nil
}

func (b *DumpBackend) StartImport() error  { return nil }
func (b *DumpBackend) FinishImport() error { return nil }

func (b *DumpBackend) ImportListens(ctx context.Context, export models.ListensResult, importResult models.ImportResult, progress chan models.TransferProgress) (models.ImportResult, error) {
	for _, listen := range export.Items {
		if err := ctx.Err(); err != nil {
			return importResult, err
		}

		importResult.UpdateTimestamp(listen.ListenedAt)
		importResult.ImportCount += 1
		msg := fmt.Sprintf("🎶 %v: \"%v\" by %v (%v)",
			listen.ListenedAt, listen.TrackName, listen.ArtistName(), listen.RecordingMBID)
		importResult.Log(models.Info, msg)
		progress <- models.TransferProgress{}.FromImportResult(importResult, false)
	}

	return importResult, nil
}

func (b *DumpBackend) ImportLoves(ctx context.Context, export models.LovesResult, importResult models.ImportResult, progress chan models.TransferProgress) (models.ImportResult, error) {
	for _, love := range export.Items {
		if err := ctx.Err(); err != nil {
			return importResult, err
		}

		importResult.UpdateTimestamp(love.Created)
		importResult.ImportCount += 1
		msg := fmt.Sprintf("❤️ %v: \"%v\" by %v (%v)",
			love.Created, love.TrackName, love.ArtistName(), love.RecordingMBID)
		importResult.Log(models.Info, msg)
		progress <- models.TransferProgress{}.FromImportResult(importResult, false)
	}

	return importResult, nil
}
